"""
passeval – offline ML-powered password strength evaluation.

Quick start
-----------
>>> from passeval import evaluate_password
>>> result = evaluate_password("Ibikoroma@009")
>>> print(result["label"])
'Strong'
"""

from .core import evaluate_password
from .features import extract_features

__all__ = ["evaluate_password", "extract_features"]
__version__ = "0.1.9"
